@@ -180,9 +180,9 @@ def getPasswdUsers(minId=1000, maxId=65000, prefix="/",
     if os.access(fileName, os.R_OK):
         reNumb = re.compile("^\d+$")
         lenData = 7
-        userData = filter(lambda x: len(x) == lenData,
-                          map(lambda x: x.rstrip().split(":"),
-                              open(fileName)))
+        with open(fileName) as f:
+            userData = filter(lambda x: len(x) == lenData,
+                              map(lambda x: x.rstrip().split(":"), f))
         userData = filter(
             lambda x: reNumb.match(x[2]) and minId <= int(x[2]) <= maxId,
             userData)
@@ -255,23 +255,24 @@ def getValueFromCmdLine(option, num=None):
             num = names.index(name)
         else:
             name = names[int(num)]
-        for param in open(cmdLine, "r").read().split(" "):
-            parname, op, value = param.partition("=")
-            if parname == calculateParam and op == "=":
-                # new format
-                if name is None:
-                    return value.strip()
-                if ":" in value:
-                    params = dict(
-                        map(lambda x: x.partition(':')[0::2],
-                            filter(lambda x: x,
-                                   value.split(','))))
-                    return params.get(name, "").strip()
-                # old format
-                else:
-                    values = value.split(",")
-                    if len(values) > num and values[num].strip():
-                        return values[num].strip()
+        with open(cmdLine, "r") as f:
+            for param in f.read().split(" "):
+                parname, op, value = param.partition("=")
+                if parname == calculateParam and op == "=":
+                    # new format
+                    if name is None:
+                        return value.strip()
+                    if ":" in value:
+                        params = dict(
+                            map(lambda x: x.partition(':')[0::2],
+                                filter(lambda x: x,
+                                       value.split(','))))
+                        return params.get(name, "").strip()
+                    # old format
+                    else:
+                        values = value.split(",")
+                        if len(values) > num and values[num].strip():
+                            return values[num].strip()
     except (IOError, ValueError, IndexError):
         return ""
 
@@ -287,7 +288,7 @@ def getValueFromConfig(config, name):
     val = None
     try:
         if path.exists(config):
-            for line in open(config, "r").readlines():
+            for line in open(config, "r"):
                 match = reMatch.match(line)
                 if match:
                     val = match.groups()[0].strip()
@@ -329,8 +330,9 @@ def getVideoFromXorgConf(prefix="/"):
     xorg_conf = path.join(prefix, 'etc/X11/xorg.conf')
     # analize /etc/X11/xorg.conf
     if path.exists(xorg_conf):
-        matchSect = re.search(r'Section "Device".*?EndSection',
-                              open(xorg_conf).read(), re.S)
+        with open(xorg_conf) as f:
+            matchSect = re.search(r'Section "Device".*?EndSection',
+                                  f.read(), re.S)
         if matchSect:
             resDriver = re.search(r'\n\s*Driver\s*"([^"]+)"',
                                   matchSect.group(0), re.S)
@@ -585,7 +587,10 @@ def getPortageUidGid():
         return 250, 250
 
 def getXorgConfContent(prefix="/"):
-    return "\n".join(open(x,'r').read() for x in 
+    def readFile(fn):
+        with open(fn, 'r') as f:
+            return f.read()
+    return "\n".join(readFile(x) for x in 
                      [path.join(prefix, "etc/X11/xorg.conf")] + 
                      glob.glob(path.join(prefix,"etc/X11/xorg.conf.d/*"))
                      if path.isfile(x))
